@@ -24,13 +24,13 @@ class StreamingResult:
 class RateLimiter:
     """速率限制器"""
 
-    def __init__(self, max_fps: Optional[float] = None):
-        self.max_fps = max_fps
-        self.min_interval = 1 / max_fps if max_fps else 0
+    def __init__(self, max_qps: Optional[float] = None):
+        self.max_qps = max_qps
+        self.min_interval = 1 / max_qps if max_qps else 0
         self.last_request_time = 0
 
     async def acquire(self):
-        if not self.max_fps:
+        if not self.max_qps:
             return
 
         current_time = time.time()
@@ -50,7 +50,7 @@ class ConcurrentRequester:
 
     requester = ConcurrentRequester(
         concurrency_limit=5,
-        max_fps=10,
+        max_qps=10,
         timeout=0.7,
     )
 
@@ -76,7 +76,7 @@ class ConcurrentRequester:
     def __init__(
             self,
             concurrency_limit: int,
-            max_fps: Optional[float] = None,
+            max_qps: Optional[float] = None,
             timeout: float | None = None,
             retry_times: int = 3,
             retry_delay: float = 0.3
@@ -86,7 +86,7 @@ class ConcurrentRequester:
             self._timeout = ClientTimeout(total=timeout, connect=min(10., timeout))
         else:
             self._timeout = None
-        self._rate_limiter = RateLimiter(max_fps)
+        self._rate_limiter = RateLimiter(max_qps)
         self._semaphore = asyncio.Semaphore(concurrency_limit)
         self.retry_times = retry_times
         self.retry_delay = retry_delay
