@@ -15,14 +15,14 @@ class OpenAIClient:
                  base_url: str,
                  api_key="EMPTY",
                  concurrency_limit=10,
-                 max_fpx=1000,
+                 max_qps=1000,
                  timeout=100,
                  retry_times=3,
                  retry_delay=0.55,
                  **kwargs):
         self._client = ConcurrentRequester(
             concurrency_limit=concurrency_limit,
-            max_fps=max_fpx,
+            max_qps=max_qps,
             timeout=timeout,
             retry_times=retry_times,
             retry_delay=retry_delay,
@@ -92,7 +92,7 @@ class OpenAIClient:
             show_progress=show_progress,
         )
         if return_raw:
-            return results, progress.summary(print_to_console=False) if return_summary else results
+            return (results, progress.summary(print_to_console=False)) if return_summary else results
         content_list = []
         for result in results:
             try:
@@ -101,7 +101,7 @@ class OpenAIClient:
                 logger.warning(f"Error in chat_completions_batch: {e}\n {result=}\n set content to None")
                 content = None
             content_list.append(content)
-        return content_list, progress.summary(print_to_console=False) if return_summary else content_list
+        return (content_list, progress.summary(print_to_console=False)) if return_summary else content_list
 
 
     def chat_completions_batch_sync(self,
